https://gitlab.com/gnutls/gnutls/-/merge_requests/1980

From 9741943dc87c46d609282a1c0bba6e19d6123c91 Mon Sep 17 00:00:00 2001
From: Daiki Ueno <ueno@gnu.org>
Date: Thu, 10 Jul 2025 05:53:32 +0900
Subject: [PATCH 1/3] tests: make cert-tests/mldsa.sh work in VPATH build

Signed-off-by: Daiki Ueno <ueno@gnu.org>
---
 tests/cert-tests/mldsa.sh | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/tests/cert-tests/mldsa.sh b/tests/cert-tests/mldsa.sh
index 7e31e113d5..55e31ce5a7 100644
--- a/tests/cert-tests/mldsa.sh
+++ b/tests/cert-tests/mldsa.sh
@@ -130,7 +130,7 @@ for variant in 44 65 87; do
 	# Check default
 	TMPKEYDEFAULT=$testdir/key-$algo-$format-default
 	TMPKEY=$testdir/key-$algo-$format
-	${VALGRIND} "${CERTTOOL}" -k --no-text --infile "data/key-$algo-$format.pem" >"$TMPKEYDEFAULT"
+	${VALGRIND} "${CERTTOOL}" -k --no-text --infile "$srcdir/data/key-$algo-$format.pem" >"$TMPKEYDEFAULT"
 	if [ $? != 0 ]; then
 	    cat "$TMPKEYDEFAULT"
 	    exit 1
@@ -138,19 +138,19 @@ for variant in 44 65 87; do
 
 	# The "expandedKey" format doesn't have public key part
 	if [ "$format" = seed ] || [ "$format" = both ]; then
-	    if ! "${DIFF}" "$TMPKEYDEFAULT" "data/key-$algo-both.pem"; then
+	    if ! "${DIFF}" "$TMPKEYDEFAULT" "$srcdir/data/key-$algo-both.pem"; then
 		exit 1
 	    fi
 	fi
 
 	# Check roundtrip with --key-format
-	${VALGRIND} "${CERTTOOL}" -k --no-text --key-format "$format" --infile "data/key-$algo-$format.pem" >"$TMPKEY"
+	${VALGRIND} "${CERTTOOL}" -k --no-text --key-format "$format" --infile "$srcdir/data/key-$algo-$format.pem" >"$TMPKEY"
 	if [ $? != 0 ]; then
 	    cat "$TMPKEY"
 	    exit 1
 	fi
 
-	if ! "${DIFF}" "$TMPKEY" "data/key-$algo-$format.pem"; then
+	if ! "${DIFF}" "$TMPKEY" "$srcdir/data/key-$algo-$format.pem"; then
 	    exit 1
 	fi
     done
@@ -164,7 +164,7 @@ for n in 1; do
     fi
 
     echo "Testing inconsistent ML-DSA key ($n)"
-    if "${CERTTOOL}" -k --infile "data/key-mldsa-inconsistent$n.pem"; then
+    if "${CERTTOOL}" -k --infile "$srcdir/data/key-mldsa-inconsistent$n.pem"; then
 	exit 1
     fi
 done
-- 
GitLab

From d2f4c53c6cdf1879101a8faa868994730485f8d3 Mon Sep 17 00:00:00 2001
From: Daiki Ueno <ueno@gnu.org>
Date: Thu, 10 Jul 2025 05:58:52 +0900
Subject: [PATCH 3/3] tests: skip system-override-compress-cert.sh if no brotli
 nor zstd

Signed-off-by: Daiki Ueno <ueno@gnu.org>
---
 tests/system-override-compress-cert.sh | 7 +++++++
 1 file changed, 7 insertions(+)

diff --git a/tests/system-override-compress-cert.sh b/tests/system-override-compress-cert.sh
index 83cf8cf9d0..afa60f2cbb 100755
--- a/tests/system-override-compress-cert.sh
+++ b/tests/system-override-compress-cert.sh
@@ -19,6 +19,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>
 
+: ${CLI=../src/gnutls-cli${EXEEXT}}
+
 TEST=${builddir}/compress-cert-conf
 CONF=config.$$.tmp
 export GNUTLS_SYSTEM_PRIORITY_FILE=${CONF}
@@ -28,6 +30,11 @@ if test "${WINDIR}" != ""; then
 	exit 77
 fi
 
+if ! "$CLI" --list | grep '^Compression: .*COMP-\(BROTLI\|ZSTD\)'; then
+	echo "Not built with brotli and zstd, skipping" 1>&2
+	exit 77
+fi
+
 cat <<_EOF_ > ${CONF}
 [overrides]
 cert-compression-alg = brotli
-- 
GitLab
